@@ -16,7 +16,11 @@
 # along with Cloud Builder.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
-from typing import NamedTuple
+from typing import (
+    NamedTuple, List
+)
+
+from kiwi.path import Path
 
 status_flags = NamedTuple(
     'status_flags', [
@@ -139,6 +143,18 @@ class Defaults:
         """
         return 'home/abuild'
 
+    @staticmethod
+    def get_package_formats() -> List[str]:
+        """
+        Return list of package format expressions used in find
+        to lookup package results
+
+        :rtype: list
+        """
+        return [
+            '*.rpm', '*.deb'
+        ]
+
     @staticmethod
     def get_cb_logfile() -> str:
         """
@@ -255,6 +271,24 @@ class Defaults:
         """
         return os.path.join(Defaults.__conf_path(), 'cbctl.yml')
 
+    @staticmethod
+    def get_kiwi() -> str:
+        """
+        Lookup kiwi binary
+
+        :return:
+            A file path or the default binary name to run kiwi-ng
+
+        :rtype: str
+        """
+        for kiwi in ['kiwi-ng', 'kiwi-ng-3']:
+            kiwi_path = Path.which(
+                kiwi, alternative_lookup_paths=['/usr/local/bin']
+            )
+            if kiwi_path:
+                return kiwi_path
+        return 'kiwi-ng'
+
     @staticmethod
     def __conf_path() -> str:
         """
